diff --git a/ReportImp/BeWoDarmstadt/BeWoDarmstadt.csproj b/ReportImp/BeWoDarmstadt/BeWoDarmstadt.csproj
index 3571cb035..239b22b97 100644
--- a/ReportImp/BeWoDarmstadt/BeWoDarmstadt.csproj
+++ b/ReportImp/BeWoDarmstadt/BeWoDarmstadt.csproj
@@ -48,9 +48,18 @@
+
+
+
+
+ Component
+
+
+ ServiceInvoiceReport.cs
+
Component
@@ -79,6 +88,10 @@
+
+ ServiceInvoiceReport.cs
+ Designer
+
Zeitzuschlagsbeleg.cs
diff --git a/ReportImp/BeWoDarmstadt/Calculations/CustomServiceRecordStatisticFactory.cs b/ReportImp/BeWoDarmstadt/Calculations/CustomServiceRecordStatisticFactory.cs
new file mode 100644
index 000000000..915f97315
--- /dev/null
+++ b/ReportImp/BeWoDarmstadt/Calculations/CustomServiceRecordStatisticFactory.cs
@@ -0,0 +1,113 @@
+using System;
+using System.Collections.Generic;
+using BeWo.Service.Plugins;
+using BS.Shared;
+using BS.Shared.DataContracts;
+
+
+namespace BeWoDarmstadt.Calculations
+{
+ public class CustomServiceRecordStatisticFactory : ServiceRecordStatisticFactory
+ {
+
+ public override ServiceRecordStatisticsInfoDC GetServiceRecordStatisticInfo(long costBearer2SupportConceptOid, DateTime statisticsDate)
+ {
+ var stats = CreateSupportConceptStatisticsImpl(costBearer2SupportConceptOid, statisticsDate);
+
+ var dc = new ServiceRecordStatisticsInfoDC();
+
+
+
+ dc.Header = new string[4];
+ dc.Header[0] = "Bewilligungszeitraum:";
+ dc.Header[1] = "Geleistet diesen Monat/Gesamt:";
+ dc.Header[2] = "Bewilligt diesen Monat/Gesamt:";
+ dc.Header[3] = "Frei diesen Monat/Gesamt:";
+
+ dc.ForegroundColor = new string[4];
+ dc.ForegroundColor[0] = "#FF2B508B";
+ dc.ForegroundColor[1] = "#FF2B508B";
+ dc.ForegroundColor[2] = "#FF2B508B";
+ dc.ForegroundColor[3] = "#FF2B508B";
+
+ dc.PeriodStatisticInfos = new List();
+
+
+ if (stats != null)
+ {
+ if (stats.PeriodStatistics.Count > 1 && !TimeSpanIsEqual(stats))
+ dc.PeriodStatisticInfos.Add(CreateTotalStatistics(stats, statisticsDate));
+
+ foreach (var pdc in stats.PeriodStatistics)
+ {
+ dc.PeriodStatisticInfos.Add(CreateServiceRecordPeriodStatisticsInfo(stats, pdc, statisticsDate));
+ }
+ }
+
+ return dc;
+ }
+
+
+ public ServiceRecordPeriodStatisticsInfoDC CreateTotalStatistics(SupportConceptStatisticsDC stats, DateTime statisticsDate)
+ {
+ var dc = CreateDefaultServiceRecordPeriodStatisticsInfo(4);
+ dc.LeftValues[0] = "Gesamt";
+
+ dc.LeftValues[1] = String.Format("{0:0.00}", stats.MinutesProvidedThisMonth / 60);
+ dc.RightValues[1] = String.Format("{0:0.00}", stats.MinutesProvidedTotalRounded / 60);
+
+ dc.LeftValues[2] = String.Format("{0:0.00}", stats.MinutesApprovedPerMonth / 60);
+ dc.RightValues[2] = String.Format("{0:0.00}", stats.MinutesApprovedTotal / 60);
+
+ dc.LeftValues[3] = String.Format("{0:0.00}", (stats.MinutesApprovedPerMonth - stats.MinutesProvidedThisMonth) / 60);
+ dc.RightValues[3] = String.Format("{0:0.00}", (stats.MinutesApprovedTotal - stats.MinutesProvidedTotalRounded) / 60);
+
+ return dc;
+ }
+
+ public ServiceRecordPeriodStatisticsInfoDC CreateServiceRecordPeriodStatisticsInfo(SupportConceptStatisticsDC stats, SupportConceptPeriodStatisticsDC periodStats, DateTime statisticsDate)
+ {
+ var dc = CreateDefaultServiceRecordPeriodStatisticsInfo(4);
+
+ if (periodStats.SupportConceptApprovalPeriod != null)
+ {
+ if (periodStats.SupportConceptApprovalPeriod.ServiceCategory != null)
+ {
+ dc.LeftValues[0] = String.Format("{0}: {1:dd.MM.yy} - {2:dd.MM.yy}",
+ periodStats.SupportConceptApprovalPeriod.ServiceCategory.Name,
+ periodStats.SupportConceptApprovalPeriod.StartDate,
+ periodStats.SupportConceptApprovalPeriod.EndDate);
+ }
+ else
+ {
+ dc.LeftValues[0] = String.Format("{0:dd.MM.yy} - {1:dd.MM.yy}",
+ periodStats.SupportConceptApprovalPeriod.StartDate,
+ periodStats.SupportConceptApprovalPeriod.EndDate);
+ }
+ }
+
+ dc.LeftValues[1] = String.Format("{0:0.00}", periodStats.MinutesProvidedThisMonth / 60);
+ dc.RightValues[1] = String.Format("{0:0.00}", periodStats.MinutesProvidedTotalRounded / 60);
+
+ dc.LeftValues[2] = String.Format("{0:0.00}", periodStats.MinutesApprovedPerMonth / 60);
+ dc.RightValues[2] = String.Format("{0:0.00}", periodStats.MinutesApprovedTotal / 60);
+
+ dc.LeftValues[3] = String.Format("{0:0.00}", (periodStats.MinutesApprovedPerMonth - periodStats.MinutesProvidedThisMonth) / 60);
+ dc.RightValues[3] = String.Format("{0:0.00}", (periodStats.MinutesApprovedTotal - periodStats.MinutesProvidedTotalRounded) / 60);
+
+ return dc;
+ }
+
+ public override decimal GetApprovedMinutesPerMonth(SupportConceptPeriodStatisticsDC periodStats)
+ {
+ if (periodStats.SupportConceptApprovalPeriod != null && periodStats.SupportConceptApprovalPeriod.StartDate.HasValue && periodStats.SupportConceptApprovalPeriod.EndDate.HasValue)
+ {
+ if (periodStats.SupportConceptApprovalPeriod.ApprovedBEPerInterval.HasValue && periodStats.SupportConceptApprovalPeriod.ApprovedBEInterval.HasValue && periodStats.SupportConceptApprovalPeriod.ApprovedBEInterval.Value == SupportConceptApprovalInterval.Monthly)
+ {
+ return periodStats.SupportConceptApprovalPeriod.ApprovedBEPerInterval.Value * 60;
+ }
+ }
+ return base.GetApprovedMinutesPerMonth(periodStats);
+ }
+ }
+}
diff --git a/ReportImp/BeWoDarmstadt/CustomMitarbeiterstundenkontoBerechnung.cs b/ReportImp/BeWoDarmstadt/CustomMitarbeiterstundenkontoBerechnung.cs
index f76a2b45c..d75f4062c 100644
--- a/ReportImp/BeWoDarmstadt/CustomMitarbeiterstundenkontoBerechnung.cs
+++ b/ReportImp/BeWoDarmstadt/CustomMitarbeiterstundenkontoBerechnung.cs
@@ -29,7 +29,7 @@ namespace BeWoDarmstadt
public override MitarbeiterstundenkontoRO.EmployeeDetail BerechneUeberstundenBis(MitarbeiterstundenkontoRO.EmployeeDetail edOrig, IList records, DateTime monat, out decimal? ueberstunden, out decimal alteExtraUeberstunden)
{
var edTotal = base.BerechneUeberstundenBis(edOrig, records, monat, out ueberstunden, out alteExtraUeberstunden);
- edOrig.Custom15 = fls;
+ edOrig.Custom15 = -fls;
// edOrig.Custom6 = ausgezahlte;
return edTotal;
}
diff --git a/ReportImp/BeWoDarmstadt/CustomReportCreator.cs b/ReportImp/BeWoDarmstadt/CustomReportCreator.cs
index f96d2e5f2..f606ad535 100644
--- a/ReportImp/BeWoDarmstadt/CustomReportCreator.cs
+++ b/ReportImp/BeWoDarmstadt/CustomReportCreator.cs
@@ -20,13 +20,11 @@ namespace BeWoDarmstadt
{
public override XtraReport CreateQueryReport(long queryOid, string queryReportId)
{
-
- if (queryOid == 200)
+ if (queryOid == 100)
{
return CreateZeitzuschlagsbeleg(queryOid, queryReportId);
}
return base.CreateQueryReport(queryOid, queryReportId);
-
}
private XtraReport CreateZeitzuschlagsbeleg(long queryOid, string queryReportId)
@@ -51,51 +49,11 @@ namespace BeWoDarmstadt
span.StartDateTime = monat;
span.EndDateTime = monat.AddMonths(1).AddTicks(-1);
- //IList teamOids = null;
-
- //if (!employeeOid.HasValue && queryOid == 500)
- //{
- // //Suche Mitarbeiter des Teams
- // ApplicationUser loggedInUser;
-
- // if (LoggedInUserOperationContextExt.Current != null &&
- // LoggedInUserOperationContextExt.Current.User != null)
- // {
- // loggedInUser = LoggedInUserOperationContextExt.Current.User;
-
-
- // }
- // else
- // {
- // loggedInUser = SessionFacade.LoggedInUser;
- // }
-
- // if (loggedInUser != null && loggedInUser.Employee != null)
- // {
- // var teams = DAOFactory.SearchDAO.FindLeadingTeams(loggedInUser.Employee.Oid.Value);
- // teamOids = teams.Select(t => t.Oid.Value).ToList();
- // }
- //}
-
MitarbeiterstundenkontoRO ro = MitarbeiterstundenkontoRO.Create(employeeOid, null, monat, monat.AddMonths(1), null);
-
var msb = new CustomMitarbeiterstundenkontoBerechnung();
msb.CreateReport(ro);
-
- //IEnumerable records = null;
-
- //if (employeeOid.HasValue && employeeOid.Value > 0)
- //{
- // records = DAOFactory.SearchDAO.FindEmployeeServiceRecords(employeeOid, span, null, null);
- //}
- //else
- //{
- // records = DAOFactory.SearchDAO.FindServiceRecordsInSpan(span, null);
- // }
-
XtraReport allReports = null;
-
foreach (var ed in ro.EmployeeDetailList)
{
diff --git a/ReportImp/BeWoDarmstadt/Invoicing/CustomInvoiceFactory.cs b/ReportImp/BeWoDarmstadt/Invoicing/CustomInvoiceFactory.cs
new file mode 100644
index 000000000..af5e74365
--- /dev/null
+++ b/ReportImp/BeWoDarmstadt/Invoicing/CustomInvoiceFactory.cs
@@ -0,0 +1,35 @@
+using System;
+using System.Collections.Generic;
+using BeWo.Data.Access;
+using BeWo.Data.Entities;
+using BeWo.Service.Invoicing;
+using BS.Shared.DataContracts;
+using BS.Shared.DataContracts.Compact;
+using BS.Shared.Services;
+
+namespace BeWoDarmstadt.Invoicing
+{
+ public class CustomInvoiceFactory : InvoiceFactory
+ {
+
+ public override InvoiceCreation CreateInvoiceCreator(string specificId, string tenant, Dictionary> supportConcepts2ServiceRecords)
+ {
+ foreach (var list in supportConcepts2ServiceRecords.Values)
+ {
+
+ foreach (var sr in list)
+ {
+ if (sr.CostBearer != null)
+ {
+ if (sr.CostBearer.Name.ToLower().Contains("selbstzahler"))
+ {
+ return new SelbstzahlerInvoiceCreation();
+ }
+ }
+ }
+ }
+
+ return new InvoiceCreation();
+ }
+ }
+}
diff --git a/ReportImp/BeWoDarmstadt/Invoicing/SelbstzahlerInvoiceCreation.cs b/ReportImp/BeWoDarmstadt/Invoicing/SelbstzahlerInvoiceCreation.cs
new file mode 100644
index 000000000..2b0fa5d01
--- /dev/null
+++ b/ReportImp/BeWoDarmstadt/Invoicing/SelbstzahlerInvoiceCreation.cs
@@ -0,0 +1,71 @@
+using BeWo.Data.Entities;
+using BeWo.Service.Invoicing;
+using BS.Shared.Core;
+using BS.Shared.DataContracts.Compact;
+using System;
+using System.Collections.Generic;
+using System.Linq;
+
+namespace BeWoDarmstadt.Invoicing
+{
+
+ public class SelbstzahlerInvoiceCreation : InvoiceCreation
+ {
+ private DateTime? accountingPeriodStart = null;
+ private DateTime? accountingPeriodEnd = null;
+
+ public override void SetInvoiceBaseData(int invoiceCounter, ServiceInvoice invoice, CostBearer costBearer, DateTimeSpan invoicePeriod,
+ IList supportConceptList)
+ {
+ if (invoicePeriod != null)
+ {
+ accountingPeriodStart = invoicePeriod.StartDate;
+ accountingPeriodEnd = invoicePeriod.EndDate;
+ }
+ base.SetInvoiceBaseData(invoiceCounter, invoice, costBearer, invoicePeriod, supportConceptList);
+ }
+
+ public override void SetRecipientInformation(ServiceInvoice serviceInvoice, CostBearer costBearer)
+ {
+ serviceInvoice.InvoiceBase.RecipientDivision = costBearer.Organisation.Name2;
+ serviceInvoice.InvoiceBase.RecipientOrganisationOid = costBearer.Organisation.Oid;
+ serviceInvoice.InvoiceBase.RecipientOrganisation = costBearer.Organisation.Name;
+ serviceInvoice.InvoiceBase.RecipientContacts = costBearer.Organisation.Contacts.Select(i => i.CopyToNew()).ToList();
+ serviceInvoice.InvoiceBase.RecipientCostBearerOid = costBearer.Oid;
+
+ if (serviceInvoice.InvoiceBase.CostBearer2SupportConcept != null)
+ {
+ var cust = serviceInvoice.InvoiceBase.CostBearer2SupportConcept.SupportConcept.Customer;
+
+ if (cust.Person.InvoiceAddress != null)
+ {
+ serviceInvoice.InvoiceBase.RecipientAddress = cust.Person.InvoiceAddress.CopyToNew();
+ }
+ else if (cust.Person.Address != null)
+ {
+ serviceInvoice.InvoiceBase.RecipientAddress = cust.Person.Address.CopyToNew();
+ }
+ //Rechnungsempfänger != Klient
+ if (cust.Person.InvoiceAddress != null && cust.Person.InvoiceAddress.AddressLine1 != null)
+ {
+ serviceInvoice.InvoiceBase.RecipientPersonFirstName = cust.Person.InvoiceAddress.AddressLine1;
+ serviceInvoice.InvoiceBase.RecipientPersonLastName = "";
+ }
+ else
+ {
+ serviceInvoice.InvoiceBase.RecipientPersonFirstName = cust.Person.FirstName;
+ serviceInvoice.InvoiceBase.RecipientPersonLastName = cust.Person.LastName;
+ }
+ return;
+ }
+ if (costBearer.Organisation.InvoiceAddress != null)
+ {
+ serviceInvoice.InvoiceBase.RecipientAddress = costBearer.Organisation.InvoiceAddress.CopyToNew();
+ }
+ else if (costBearer.Organisation.Address != null)
+ {
+ serviceInvoice.InvoiceBase.RecipientAddress = costBearer.Organisation.Address.CopyToNew();
+ }
+ }
+ }
+}
\ No newline at end of file
diff --git a/ReportImp/BeWoDarmstadt/ServiceInvoiceReport.Designer.cs b/ReportImp/BeWoDarmstadt/ServiceInvoiceReport.Designer.cs
new file mode 100644
index 000000000..d14c30b71
--- /dev/null
+++ b/ReportImp/BeWoDarmstadt/ServiceInvoiceReport.Designer.cs
@@ -0,0 +1,883 @@
+using BeWo.Report.ReportObjects;
+namespace BeWoDarmstadt
+{
+ partial class ServiceInvoiceReport
+ {
+ ///
+ /// Required designer variable.
+ ///
+ private System.ComponentModel.IContainer components = null;
+
+ ///
+ /// Clean up any resources being used.
+ ///
+ /// true if managed resources should be disposed; otherwise, false.
+ protected override void Dispose(bool disposing)
+ {
+ if (disposing && (components != null))
+ {
+ components.Dispose();
+ }
+ base.Dispose(disposing);
+ }
+
+
+ ///
+ /// Required method for Designer support - do not modify
+ /// the contents of this method with the code editor.
+ ///
+ private void InitializeComponent()
+ {
+ this.components = new System.ComponentModel.Container();
+ this.Detail = new DevExpress.XtraReports.UI.DetailBand();
+ this.ReportHeader = new DevExpress.XtraReports.UI.ReportHeaderBand();
+ this.ruleRateFactorNull = new DevExpress.XtraReports.UI.FormattingRule();
+ this.topMarginBand1 = new DevExpress.XtraReports.UI.TopMarginBand();
+ this.bottomMarginBand1 = new DevExpress.XtraReports.UI.BottomMarginBand();
+ this.Page1 = new DevExpress.XtraReports.UI.GroupHeaderBand();
+ this.lblAdresse = new DevExpress.XtraReports.UI.XRLabel();
+ this.xrLabel4 = new DevExpress.XtraReports.UI.XRLabel();
+ this.xrLabel3 = new DevExpress.XtraReports.UI.XRLabel();
+ this.xrLabel2 = new DevExpress.XtraReports.UI.XRLabel();
+ this.xrLabel5 = new DevExpress.XtraReports.UI.XRLabel();
+ this.xrLabel8 = new DevExpress.XtraReports.UI.XRLabel();
+ this.lblAbrechnungszeitraum = new DevExpress.XtraReports.UI.XRLabel();
+ this.xrTable2 = new DevExpress.XtraReports.UI.XRTable();
+ this.xrTableRow2 = new DevExpress.XtraReports.UI.XRTableRow();
+ this.xrTableCell4 = new DevExpress.XtraReports.UI.XRTableCell();
+ this.xrTableRow5 = new DevExpress.XtraReports.UI.XRTableRow();
+ this.xrTableCell13 = new DevExpress.XtraReports.UI.XRTableCell();
+ this.xrTableRow4 = new DevExpress.XtraReports.UI.XRTableRow();
+ this.xrTableCell11 = new DevExpress.XtraReports.UI.XRTableCell();
+ this.xrTableRow3 = new DevExpress.XtraReports.UI.XRTableRow();
+ this.xrTableCell8 = new DevExpress.XtraReports.UI.XRTableCell();
+ this.xrTableRow1 = new DevExpress.XtraReports.UI.XRTableRow();
+ this.xrTableCell1 = new DevExpress.XtraReports.UI.XRTableCell();
+ this.xrTableRow6 = new DevExpress.XtraReports.UI.XRTableRow();
+ this.xrTableCell2 = new DevExpress.XtraReports.UI.XRTableCell();
+ this.xrTableRow8 = new DevExpress.XtraReports.UI.XRTableRow();
+ this.xrTableCell5 = new DevExpress.XtraReports.UI.XRTableCell();
+ this.xrLabel15 = new DevExpress.XtraReports.UI.XRLabel();
+ this.xrTable4 = new DevExpress.XtraReports.UI.XRTable();
+ this.xrTableRow10 = new DevExpress.XtraReports.UI.XRTableRow();
+ this.xrTableCell9 = new DevExpress.XtraReports.UI.XRTableCell();
+ this.xrTableRow14 = new DevExpress.XtraReports.UI.XRTableRow();
+ this.xrTableCell12 = new DevExpress.XtraReports.UI.XRTableCell();
+ this.xrLabel14 = new DevExpress.XtraReports.UI.XRLabel();
+ this.xrLabel9 = new DevExpress.XtraReports.UI.XRLabel();
+ this.DetailReport = new DevExpress.XtraReports.UI.DetailReportBand();
+ this.Detail1 = new DevExpress.XtraReports.UI.DetailBand();
+ this.xrTable5 = new DevExpress.XtraReports.UI.XRTable();
+ this.xrTableRow23 = new DevExpress.XtraReports.UI.XRTableRow();
+ this.xrTableCell32 = new DevExpress.XtraReports.UI.XRTableCell();
+ this.xrTableCell37 = new DevExpress.XtraReports.UI.XRTableCell();
+ this.xrTableCell35 = new DevExpress.XtraReports.UI.XRTableCell();
+ this.xrTableCell33 = new DevExpress.XtraReports.UI.XRTableCell();
+ this.xrTableCell36 = new DevExpress.XtraReports.UI.XRTableCell();
+ this.xrTableCell38 = new DevExpress.XtraReports.UI.XRTableCell();
+ this.xrTableCell34 = new DevExpress.XtraReports.UI.XRTableCell();
+ this.DetailReport2 = new DevExpress.XtraReports.UI.DetailReportBand();
+ this.Detail3 = new DevExpress.XtraReports.UI.DetailBand();
+ this.xrTable6 = new DevExpress.XtraReports.UI.XRTable();
+ this.xrTableRow25 = new DevExpress.XtraReports.UI.XRTableRow();
+ this.xrTableCell40 = new DevExpress.XtraReports.UI.XRTableCell();
+ this.xrTableCell42 = new DevExpress.XtraReports.UI.XRTableCell();
+ this.xrTableCell43 = new DevExpress.XtraReports.UI.XRTableCell();
+ this.xrTableCell44 = new DevExpress.XtraReports.UI.XRTableCell();
+ this.xrTableCell45 = new DevExpress.XtraReports.UI.XRTableCell();
+ this.xrTableCell46 = new DevExpress.XtraReports.UI.XRTableCell();
+ this.xrTableCell47 = new DevExpress.XtraReports.UI.XRTableCell();
+ this.GroupFooter1 = new DevExpress.XtraReports.UI.GroupFooterBand();
+ this.xrLabel1 = new DevExpress.XtraReports.UI.XRLabel();
+ this.bindingSource1 = new System.Windows.Forms.BindingSource(this.components);
+ ((System.ComponentModel.ISupportInitialize)(this.xrTable2)).BeginInit();
+ ((System.ComponentModel.ISupportInitialize)(this.xrTable4)).BeginInit();
+ ((System.ComponentModel.ISupportInitialize)(this.xrTable5)).BeginInit();
+ ((System.ComponentModel.ISupportInitialize)(this.xrTable6)).BeginInit();
+ ((System.ComponentModel.ISupportInitialize)(this.bindingSource1)).BeginInit();
+ ((System.ComponentModel.ISupportInitialize)(this)).BeginInit();
+ //
+ // Detail
+ //
+ this.Detail.HeightF = 0F;
+ this.Detail.Name = "Detail";
+ this.Detail.Padding = new DevExpress.XtraPrinting.PaddingInfo(0, 0, 0, 0, 100F);
+ this.Detail.TextAlignment = DevExpress.XtraPrinting.TextAlignment.TopLeft;
+ //
+ // ReportHeader
+ //
+ this.ReportHeader.Font = new System.Drawing.Font("Verdana", 10F);
+ this.ReportHeader.HeightF = 0F;
+ this.ReportHeader.Name = "ReportHeader";
+ this.ReportHeader.StylePriority.UseFont = false;
+ //
+ // ruleRateFactorNull
+ //
+ this.ruleRateFactorNull.Condition = "[RateFactorText2] == ?";
+ this.ruleRateFactorNull.Formatting.Visible = DevExpress.Utils.DefaultBoolean.False;
+ this.ruleRateFactorNull.Name = "ruleRateFactorNull";
+ //
+ // topMarginBand1
+ //
+ this.topMarginBand1.HeightF = 157.5F;
+ this.topMarginBand1.Name = "topMarginBand1";
+ //
+ // bottomMarginBand1
+ //
+ this.bottomMarginBand1.HeightF = 50F;
+ this.bottomMarginBand1.Name = "bottomMarginBand1";
+ //
+ // Page1
+ //
+ this.Page1.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
+ this.lblAdresse,
+ this.xrLabel4,
+ this.xrLabel3,
+ this.xrLabel2,
+ this.xrLabel5,
+ this.xrLabel8,
+ this.lblAbrechnungszeitraum,
+ this.xrTable2});
+ this.Page1.Font = new System.Drawing.Font("Verdana", 10F);
+ this.Page1.HeightF = 354.0833F;
+ this.Page1.Name = "Page1";
+ this.Page1.StylePriority.UseFont = false;
+ //
+ // lblAdresse
+ //
+ this.lblAdresse.LocationFloat = new DevExpress.Utils.PointFloat(0F, 0F);
+ this.lblAdresse.Multiline = true;
+ this.lblAdresse.Name = "lblAdresse";
+ this.lblAdresse.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 0, 0, 100F);
+ this.lblAdresse.SizeF = new System.Drawing.SizeF(317F, 111.5F);
+ this.lblAdresse.StylePriority.UseFont = false;
+ //
+ // xrLabel4
+ //
+ this.xrLabel4.BackColor = System.Drawing.Color.Transparent;
+ this.xrLabel4.CanShrink = true;
+ this.xrLabel4.Font = new System.Drawing.Font("Verdana", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
+ this.xrLabel4.LocationFloat = new DevExpress.Utils.PointFloat(0F, 235F);
+ this.xrLabel4.Multiline = true;
+ this.xrLabel4.Name = "xrLabel4";
+ this.xrLabel4.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 0, 0, 100F);
+ this.xrLabel4.SizeF = new System.Drawing.SizeF(650F, 20F);
+ this.xrLabel4.StylePriority.UseBackColor = false;
+ this.xrLabel4.StylePriority.UseFont = false;
+ this.xrLabel4.Text = "[CustomerReferenceNumber]";
+ this.xrLabel4.WordWrap = false;
+ //
+ // xrLabel3
+ //
+ this.xrLabel3.BackColor = System.Drawing.Color.Transparent;
+ this.xrLabel3.CanShrink = true;
+ this.xrLabel3.Font = new System.Drawing.Font("Verdana", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
+ this.xrLabel3.LocationFloat = new DevExpress.Utils.PointFloat(0F, 215F);
+ this.xrLabel3.Name = "xrLabel3";
+ this.xrLabel3.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 0, 0, 100F);
+ this.xrLabel3.SizeF = new System.Drawing.SizeF(650F, 20F);
+ this.xrLabel3.StylePriority.UseBackColor = false;
+ this.xrLabel3.StylePriority.UseFont = false;
+ this.xrLabel3.Text = "Abrechnung Betreuungsleistungen für [CustomerSalutation] [CustomerName]";
+ this.xrLabel3.WordWrap = false;
+ //
+ // xrLabel2
+ //
+ this.xrLabel2.BackColor = System.Drawing.Color.Transparent;
+ this.xrLabel2.CanShrink = true;
+ this.xrLabel2.Font = new System.Drawing.Font("Verdana", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
+ this.xrLabel2.LocationFloat = new DevExpress.Utils.PointFloat(0F, 195F);
+ this.xrLabel2.Name = "xrLabel2";
+ this.xrLabel2.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 0, 0, 100F);
+ this.xrLabel2.SizeF = new System.Drawing.SizeF(650F, 20F);
+ this.xrLabel2.StylePriority.UseBackColor = false;
+ this.xrLabel2.StylePriority.UseFont = false;
+ this.xrLabel2.Text = "Rechnung Nr. [InvoiceNumber]";
+ this.xrLabel2.WordWrap = false;
+ //
+ // xrLabel5
+ //
+ this.xrLabel5.LocationFloat = new DevExpress.Utils.PointFloat(0F, 297.5F);
+ this.xrLabel5.Name = "xrLabel5";
+ this.xrLabel5.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 0, 0, 100F);
+ this.xrLabel5.SizeF = new System.Drawing.SizeF(317F, 17F);
+ this.xrLabel5.StylePriority.UseFont = false;
+ this.xrLabel5.Text = "Sehr geehrte Damen und Herren,";
+ //
+ // xrLabel8
+ //
+ this.xrLabel8.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
+ new DevExpress.XtraReports.UI.XRBinding("Text", null, "InvoiceDate")});
+ this.xrLabel8.LocationFloat = new DevExpress.Utils.PointFloat(362.5F, 172F);
+ this.xrLabel8.Name = "xrLabel8";
+ this.xrLabel8.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 0, 0, 100F);
+ this.xrLabel8.SizeF = new System.Drawing.SizeF(283F, 23F);
+ this.xrLabel8.StylePriority.UseTextAlignment = false;
+ this.xrLabel8.Text = "xrLabel8";
+ this.xrLabel8.TextAlignment = DevExpress.XtraPrinting.TextAlignment.TopRight;
+ //
+ // lblAbrechnungszeitraum
+ //
+ this.lblAbrechnungszeitraum.LocationFloat = new DevExpress.Utils.PointFloat(0F, 322.5F);
+ this.lblAbrechnungszeitraum.Multiline = true;
+ this.lblAbrechnungszeitraum.Name = "lblAbrechnungszeitraum";
+ this.lblAbrechnungszeitraum.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 0, 0, 100F);
+ this.lblAbrechnungszeitraum.SizeF = new System.Drawing.SizeF(642F, 31.58334F);
+ this.lblAbrechnungszeitraum.StylePriority.UseFont = false;
+ this.lblAbrechnungszeitraum.Text = "hiermit berechnen wir für den ... folgende erbrachte Tätigkeiten:";
+ //
+ // xrTable2
+ //
+ this.xrTable2.LocationFloat = new DevExpress.Utils.PointFloat(362.5F, 0F);
+ this.xrTable2.Name = "xrTable2";
+ this.xrTable2.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
+ this.xrTableRow2,
+ this.xrTableRow5,
+ this.xrTableRow4,
+ this.xrTableRow3,
+ this.xrTableRow1,
+ this.xrTableRow6,
+ this.xrTableRow8});
+ this.xrTable2.SizeF = new System.Drawing.SizeF(283F, 134F);
+ //
+ // xrTableRow2
+ //
+ this.xrTableRow2.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
+ this.xrTableCell4});
+ this.xrTableRow2.Name = "xrTableRow2";
+ this.xrTableRow2.Weight = 0.13245033112582783D;
+ //
+ // xrTableCell4
+ //
+ this.xrTableCell4.CanShrink = true;
+ this.xrTableCell4.Name = "xrTableCell4";
+ this.xrTableCell4.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 0, 0, 100F);
+ this.xrTableCell4.ProcessNullValues = DevExpress.XtraReports.UI.ValueSuppressType.SuppressAndShrink;
+ this.xrTableCell4.StylePriority.UseFont = false;
+ this.xrTableCell4.StylePriority.UseTextAlignment = false;
+ this.xrTableCell4.Text = "Ihr(e) Ansprechpartner(in):";
+ this.xrTableCell4.TextAlignment = DevExpress.XtraPrinting.TextAlignment.TopRight;
+ this.xrTableCell4.Weight = 1D;
+ //
+ // xrTableRow5
+ //
+ this.xrTableRow5.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
+ this.xrTableCell13});
+ this.xrTableRow5.Name = "xrTableRow5";
+ this.xrTableRow5.Weight = 0.13245033112582783D;
+ //
+ // xrTableCell13
+ //
+ this.xrTableCell13.CanShrink = true;
+ this.xrTableCell13.Name = "xrTableCell13";
+ this.xrTableCell13.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 0, 0, 100F);
+ this.xrTableCell13.ProcessNullValues = DevExpress.XtraReports.UI.ValueSuppressType.SuppressAndShrink;
+ this.xrTableCell13.StylePriority.UseFont = false;
+ this.xrTableCell13.StylePriority.UseTextAlignment = false;
+ this.xrTableCell13.Text = "[SenderContactPerson]";
+ this.xrTableCell13.TextAlignment = DevExpress.XtraPrinting.TextAlignment.TopRight;
+ this.xrTableCell13.Weight = 1D;
+ //
+ // xrTableRow4
+ //
+ this.xrTableRow4.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
+ this.xrTableCell11});
+ this.xrTableRow4.Name = "xrTableRow4";
+ this.xrTableRow4.Weight = 0.13245033112582783D;
+ //
+ // xrTableCell11
+ //
+ this.xrTableCell11.CanShrink = true;
+ this.xrTableCell11.Name = "xrTableCell11";
+ this.xrTableCell11.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 0, 0, 100F);
+ this.xrTableCell11.ProcessNullValues = DevExpress.XtraReports.UI.ValueSuppressType.SuppressAndShrink;
+ this.xrTableCell11.StylePriority.UseFont = false;
+ this.xrTableCell11.StylePriority.UseTextAlignment = false;
+ this.xrTableCell11.Text = "[SenderContactPersonDivision]";
+ this.xrTableCell11.TextAlignment = DevExpress.XtraPrinting.TextAlignment.TopRight;
+ this.xrTableCell11.Weight = 1D;
+ //
+ // xrTableRow3
+ //
+ this.xrTableRow3.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
+ this.xrTableCell8});
+ this.xrTableRow3.Name = "xrTableRow3";
+ this.xrTableRow3.Weight = 0.13245033112582783D;
+ //
+ // xrTableCell8
+ //
+ this.xrTableCell8.CanShrink = true;
+ this.xrTableCell8.Name = "xrTableCell8";
+ this.xrTableCell8.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 0, 0, 100F);
+ this.xrTableCell8.ProcessNullValues = DevExpress.XtraReports.UI.ValueSuppressType.SuppressAndShrink;
+ this.xrTableCell8.StylePriority.UseFont = false;
+ this.xrTableCell8.StylePriority.UseTextAlignment = false;
+ this.xrTableCell8.Text = "[SenderContactPersonMail]";
+ this.xrTableCell8.TextAlignment = DevExpress.XtraPrinting.TextAlignment.TopRight;
+ this.xrTableCell8.Weight = 1D;
+ //
+ // xrTableRow1
+ //
+ this.xrTableRow1.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
+ this.xrTableCell1});
+ this.xrTableRow1.Name = "xrTableRow1";
+ this.xrTableRow1.Weight = 0.13245033112582783D;
+ //
+ // xrTableCell1
+ //
+ this.xrTableCell1.CanShrink = true;
+ this.xrTableCell1.Name = "xrTableCell1";
+ this.xrTableCell1.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 0, 0, 100F);
+ this.xrTableCell1.ProcessNullValues = DevExpress.XtraReports.UI.ValueSuppressType.SuppressAndShrink;
+ this.xrTableCell1.StylePriority.UseFont = false;
+ this.xrTableCell1.StylePriority.UseTextAlignment = false;
+ this.xrTableCell1.Text = "[SenderContactPersonPhone]";
+ this.xrTableCell1.TextAlignment = DevExpress.XtraPrinting.TextAlignment.TopRight;
+ this.xrTableCell1.Weight = 1D;
+ //
+ // xrTableRow6
+ //
+ this.xrTableRow6.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
+ this.xrTableCell2});
+ this.xrTableRow6.Name = "xrTableRow6";
+ this.xrTableRow6.Weight = 0.11258278145695365D;
+ //
+ // xrTableCell2
+ //
+ this.xrTableCell2.CanShrink = true;
+ this.xrTableCell2.Name = "xrTableCell2";
+ this.xrTableCell2.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 0, 0, 100F);
+ this.xrTableCell2.ProcessNullValues = DevExpress.XtraReports.UI.ValueSuppressType.SuppressAndShrink;
+ this.xrTableCell2.StylePriority.UseFont = false;
+ this.xrTableCell2.StylePriority.UseTextAlignment = false;
+ this.xrTableCell2.Text = "[SenderContactPersonFax]";
+ this.xrTableCell2.TextAlignment = DevExpress.XtraPrinting.TextAlignment.TopRight;
+ this.xrTableCell2.Weight = 1D;
+ //
+ // xrTableRow8
+ //
+ this.xrTableRow8.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
+ this.xrTableCell5});
+ this.xrTableRow8.Name = "xrTableRow8";
+ this.xrTableRow8.Weight = 0.11258278145695365D;
+ //
+ // xrTableCell5
+ //
+ this.xrTableCell5.Name = "xrTableCell5";
+ this.xrTableCell5.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 0, 0, 100F);
+ this.xrTableCell5.Weight = 1D;
+ //
+ // xrLabel15
+ //
+ this.xrLabel15.Font = new System.Drawing.Font("Verdana", 10F);
+ this.xrLabel15.LocationFloat = new DevExpress.Utils.PointFloat(0F, 114.5833F);
+ this.xrLabel15.Name = "xrLabel15";
+ this.xrLabel15.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 0, 0, 100F);
+ this.xrLabel15.SizeF = new System.Drawing.SizeF(175F, 17F);
+ this.xrLabel15.StylePriority.UseFont = false;
+ this.xrLabel15.Text = "Mit freundlichen Grüßen";
+ //
+ // xrTable4
+ //
+ this.xrTable4.Font = new System.Drawing.Font("Verdana", 10F);
+ this.xrTable4.LocationFloat = new DevExpress.Utils.PointFloat(0F, 68.75F);
+ this.xrTable4.Name = "xrTable4";
+ this.xrTable4.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
+ this.xrTableRow10,
+ this.xrTableRow14});
+ this.xrTable4.SizeF = new System.Drawing.SizeF(650F, 26F);
+ this.xrTable4.StylePriority.UseFont = false;
+ //
+ // xrTableRow10
+ //
+ this.xrTableRow10.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
+ this.xrTableCell9});
+ this.xrTableRow10.Name = "xrTableRow10";
+ this.xrTableRow10.Weight = 0.38095238095238093D;
+ //
+ // xrTableCell9
+ //
+ this.xrTableCell9.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
+ new DevExpress.XtraReports.UI.XRBinding("Text", null, "Notice")});
+ this.xrTableCell9.Name = "xrTableCell9";
+ this.xrTableCell9.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 0, 0, 100F);
+ this.xrTableCell9.StylePriority.UsePadding = false;
+ this.xrTableCell9.Text = "xrTableCell1";
+ this.xrTableCell9.Weight = 3D;
+ //
+ // xrTableRow14
+ //
+ this.xrTableRow14.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
+ this.xrTableCell12});
+ this.xrTableRow14.Name = "xrTableRow14";
+ this.xrTableRow14.Weight = 0.23809523809523808D;
+ //
+ // xrTableCell12
+ //
+ this.xrTableCell12.Name = "xrTableCell12";
+ this.xrTableCell12.Weight = 3D;
+ //
+ // xrLabel14
+ //
+ this.xrLabel14.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
+ new DevExpress.XtraReports.UI.XRBinding("Text", null, "CreatorName")});
+ this.xrLabel14.Font = new System.Drawing.Font("Verdana", 10F);
+ this.xrLabel14.LocationFloat = new DevExpress.Utils.PointFloat(0F, 189.5833F);
+ this.xrLabel14.Name = "xrLabel14";
+ this.xrLabel14.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 0, 0, 100F);
+ this.xrLabel14.SizeF = new System.Drawing.SizeF(225F, 17F);
+ this.xrLabel14.StylePriority.UseFont = false;
+ this.xrLabel14.Text = "[CreatorName]";
+ //
+ // xrLabel9
+ //
+ this.xrLabel9.Font = new System.Drawing.Font("Verdana", 10F, System.Drawing.FontStyle.Italic);
+ this.xrLabel9.LocationFloat = new DevExpress.Utils.PointFloat(0F, 43.75F);
+ this.xrLabel9.Name = "xrLabel9";
+ this.xrLabel9.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 0, 0, 100F);
+ this.xrLabel9.SizeF = new System.Drawing.SizeF(250F, 17F);
+ this.xrLabel9.StylePriority.UseFont = false;
+ this.xrLabel9.Text = "Abschließende Bemerkungen:";
+ //
+ // DetailReport
+ //
+ this.DetailReport.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
+ this.Detail1,
+ this.DetailReport2});
+ this.DetailReport.DataMember = "ServiceInvoicePeriods";
+ this.DetailReport.DataSource = this.bindingSource1;
+ this.DetailReport.Level = 0;
+ this.DetailReport.Name = "DetailReport";
+ //
+ // Detail1
+ //
+ this.Detail1.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
+ this.xrTable5});
+ this.Detail1.HeightF = 25F;
+ this.Detail1.Name = "Detail1";
+ //
+ // xrTable5
+ //
+ this.xrTable5.LocationFloat = new DevExpress.Utils.PointFloat(0F, 0F);
+ this.xrTable5.Name = "xrTable5";
+ this.xrTable5.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
+ this.xrTableRow23});
+ this.xrTable5.SizeF = new System.Drawing.SizeF(677F, 25F);
+ //
+ // xrTableRow23
+ //
+ this.xrTableRow23.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
+ this.xrTableCell32,
+ this.xrTableCell37,
+ this.xrTableCell35,
+ this.xrTableCell33,
+ this.xrTableCell36,
+ this.xrTableCell38,
+ this.xrTableCell34});
+ this.xrTableRow23.Name = "xrTableRow23";
+ this.xrTableRow23.Weight = 1D;
+ //
+ // xrTableCell32
+ //
+ this.xrTableCell32.BackColor = System.Drawing.Color.Gainsboro;
+ this.xrTableCell32.BorderColor = System.Drawing.Color.DarkGray;
+ this.xrTableCell32.Borders = ((DevExpress.XtraPrinting.BorderSide)((((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Top)
+ | DevExpress.XtraPrinting.BorderSide.Right)
+ | DevExpress.XtraPrinting.BorderSide.Bottom)));
+ this.xrTableCell32.Name = "xrTableCell32";
+ this.xrTableCell32.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 2, 2, 100F);
+ this.xrTableCell32.StylePriority.UseBackColor = false;
+ this.xrTableCell32.StylePriority.UseBorderColor = false;
+ this.xrTableCell32.StylePriority.UseBorders = false;
+ this.xrTableCell32.StylePriority.UsePadding = false;
+ this.xrTableCell32.StylePriority.UseTextAlignment = false;
+ this.xrTableCell32.Text = "Zeitraum";
+ this.xrTableCell32.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleLeft;
+ this.xrTableCell32.Weight = 0.62463077449375981D;
+ //
+ // xrTableCell37
+ //
+ this.xrTableCell37.BackColor = System.Drawing.Color.Gainsboro;
+ this.xrTableCell37.BorderColor = System.Drawing.Color.DarkGray;
+ this.xrTableCell37.Borders = ((DevExpress.XtraPrinting.BorderSide)((((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Top)
+ | DevExpress.XtraPrinting.BorderSide.Right)
+ | DevExpress.XtraPrinting.BorderSide.Bottom)));
+ this.xrTableCell37.Name = "xrTableCell37";
+ this.xrTableCell37.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 2, 2, 100F);
+ this.xrTableCell37.StylePriority.UseBackColor = false;
+ this.xrTableCell37.StylePriority.UseBorderColor = false;
+ this.xrTableCell37.StylePriority.UseBorders = false;
+ this.xrTableCell37.StylePriority.UsePadding = false;
+ this.xrTableCell37.StylePriority.UseTextAlignment = false;
+ this.xrTableCell37.Text = "Leistung";
+ this.xrTableCell37.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleLeft;
+ this.xrTableCell37.Weight = 0.85081236260328186D;
+ //
+ // xrTableCell35
+ //
+ this.xrTableCell35.BackColor = System.Drawing.Color.Gainsboro;
+ this.xrTableCell35.BorderColor = System.Drawing.Color.DarkGray;
+ this.xrTableCell35.Borders = ((DevExpress.XtraPrinting.BorderSide)((((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Top)
+ | DevExpress.XtraPrinting.BorderSide.Right)
+ | DevExpress.XtraPrinting.BorderSide.Bottom)));
+ this.xrTableCell35.Name = "xrTableCell35";
+ this.xrTableCell35.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 2, 2, 100F);
+ this.xrTableCell35.StylePriority.UseBackColor = false;
+ this.xrTableCell35.StylePriority.UseBorderColor = false;
+ this.xrTableCell35.StylePriority.UseBorders = false;
+ this.xrTableCell35.StylePriority.UsePadding = false;
+ this.xrTableCell35.StylePriority.UseTextAlignment = false;
+ this.xrTableCell35.Text = "Satz";
+ this.xrTableCell35.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
+ this.xrTableCell35.Weight = 0.23245943032832414D;
+ //
+ // xrTableCell33
+ //
+ this.xrTableCell33.BackColor = System.Drawing.Color.Gainsboro;
+ this.xrTableCell33.BorderColor = System.Drawing.Color.DarkGray;
+ this.xrTableCell33.Borders = ((DevExpress.XtraPrinting.BorderSide)((((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Top)
+ | DevExpress.XtraPrinting.BorderSide.Right)
+ | DevExpress.XtraPrinting.BorderSide.Bottom)));
+ this.xrTableCell33.Name = "xrTableCell33";
+ this.xrTableCell33.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 2, 2, 100F);
+ this.xrTableCell33.StylePriority.UseBackColor = false;
+ this.xrTableCell33.StylePriority.UseBorderColor = false;
+ this.xrTableCell33.StylePriority.UseBorders = false;
+ this.xrTableCell33.StylePriority.UsePadding = false;
+ this.xrTableCell33.StylePriority.UseTextAlignment = false;
+ this.xrTableCell33.Text = "Stunden";
+ this.xrTableCell33.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
+ this.xrTableCell33.Weight = 0.2893277257020575D;
+ //
+ // xrTableCell36
+ //
+ this.xrTableCell36.BackColor = System.Drawing.Color.Gainsboro;
+ this.xrTableCell36.BorderColor = System.Drawing.Color.DarkGray;
+ this.xrTableCell36.Borders = ((DevExpress.XtraPrinting.BorderSide)((((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Top)
+ | DevExpress.XtraPrinting.BorderSide.Right)
+ | DevExpress.XtraPrinting.BorderSide.Bottom)));
+ this.xrTableCell36.Name = "xrTableCell36";
+ this.xrTableCell36.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 2, 2, 100F);
+ this.xrTableCell36.StylePriority.UseBackColor = false;
+ this.xrTableCell36.StylePriority.UseBorderColor = false;
+ this.xrTableCell36.StylePriority.UseBorders = false;
+ this.xrTableCell36.StylePriority.UsePadding = false;
+ this.xrTableCell36.StylePriority.UseTextAlignment = false;
+ this.xrTableCell36.Text = "Betrag";
+ this.xrTableCell36.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
+ this.xrTableCell36.Weight = 0.26310971709438763D;
+ //
+ // xrTableCell38
+ //
+ this.xrTableCell38.BackColor = System.Drawing.Color.Gainsboro;
+ this.xrTableCell38.BorderColor = System.Drawing.Color.DarkGray;
+ this.xrTableCell38.Borders = ((DevExpress.XtraPrinting.BorderSide)((((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Top)
+ | DevExpress.XtraPrinting.BorderSide.Right)
+ | DevExpress.XtraPrinting.BorderSide.Bottom)));
+ this.xrTableCell38.Name = "xrTableCell38";
+ this.xrTableCell38.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 2, 2, 100F);
+ this.xrTableCell38.StylePriority.UseBackColor = false;
+ this.xrTableCell38.StylePriority.UseBorderColor = false;
+ this.xrTableCell38.StylePriority.UseBorders = false;
+ this.xrTableCell38.StylePriority.UsePadding = false;
+ this.xrTableCell38.StylePriority.UseTextAlignment = false;
+ this.xrTableCell38.Text = "pausch Fakt.";
+ this.xrTableCell38.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
+ this.xrTableCell38.Weight = 0.42042083402151886D;
+ //
+ // xrTableCell34
+ //
+ this.xrTableCell34.BackColor = System.Drawing.Color.Gainsboro;
+ this.xrTableCell34.BorderColor = System.Drawing.Color.DarkGray;
+ this.xrTableCell34.Borders = ((DevExpress.XtraPrinting.BorderSide)((((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Top)
+ | DevExpress.XtraPrinting.BorderSide.Right)
+ | DevExpress.XtraPrinting.BorderSide.Bottom)));
+ this.xrTableCell34.Name = "xrTableCell34";
+ this.xrTableCell34.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 2, 2, 100F);
+ this.xrTableCell34.StylePriority.UseBackColor = false;
+ this.xrTableCell34.StylePriority.UseBorderColor = false;
+ this.xrTableCell34.StylePriority.UseBorders = false;
+ this.xrTableCell34.StylePriority.UsePadding = false;
+ this.xrTableCell34.StylePriority.UseTextAlignment = false;
+ this.xrTableCell34.Text = "Gesamt";
+ this.xrTableCell34.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
+ this.xrTableCell34.Weight = 0.31923915575667006D;
+ //
+ // DetailReport2
+ //
+ this.DetailReport2.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
+ this.Detail3,
+ this.GroupFooter1});
+ this.DetailReport2.DataMember = "ServiceInvoicePeriods.ServiceInvoiceItems";
+ this.DetailReport2.DataSource = this.bindingSource1;
+ this.DetailReport2.Level = 0;
+ this.DetailReport2.Name = "DetailReport2";
+ this.DetailReport2.PageBreak = DevExpress.XtraReports.UI.PageBreak.AfterBand;
+ //
+ // Detail3
+ //
+ this.Detail3.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
+ this.xrTable6});
+ this.Detail3.HeightF = 25F;
+ this.Detail3.Name = "Detail3";
+ //
+ // xrTable6
+ //
+ this.xrTable6.Font = new System.Drawing.Font("Verdana", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
+ this.xrTable6.LocationFloat = new DevExpress.Utils.PointFloat(0F, 0F);
+ this.xrTable6.Name = "xrTable6";
+ this.xrTable6.Rows.AddRange(new DevExpress.XtraReports.UI.XRTableRow[] {
+ this.xrTableRow25});
+ this.xrTable6.SizeF = new System.Drawing.SizeF(677F, 25F);
+ this.xrTable6.StylePriority.UseFont = false;
+ //
+ // xrTableRow25
+ //
+ this.xrTableRow25.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
+ this.xrTableCell40,
+ this.xrTableCell42,
+ this.xrTableCell43,
+ this.xrTableCell44,
+ this.xrTableCell45,
+ this.xrTableCell46,
+ this.xrTableCell47});
+ this.xrTableRow25.Name = "xrTableRow25";
+ this.xrTableRow25.Weight = 1D;
+ //
+ // xrTableCell40
+ //
+ this.xrTableCell40.BorderColor = System.Drawing.Color.DarkGray;
+ this.xrTableCell40.Borders = ((DevExpress.XtraPrinting.BorderSide)(((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Right)
+ | DevExpress.XtraPrinting.BorderSide.Bottom)));
+ this.xrTableCell40.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
+ new DevExpress.XtraReports.UI.XRBinding("Text", null, "ServiceInvoicePeriods.ServiceInvoiceItems.Duration")});
+ this.xrTableCell40.Name = "xrTableCell40";
+ this.xrTableCell40.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 2, 2, 100F);
+ this.xrTableCell40.StylePriority.UseBorderColor = false;
+ this.xrTableCell40.StylePriority.UseBorders = false;
+ this.xrTableCell40.StylePriority.UsePadding = false;
+ this.xrTableCell40.StylePriority.UseTextAlignment = false;
+ this.xrTableCell40.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleLeft;
+ this.xrTableCell40.Weight = 0.62463084211025488D;
+ //
+ // xrTableCell42
+ //
+ this.xrTableCell42.BorderColor = System.Drawing.Color.DarkGray;
+ this.xrTableCell42.Borders = ((DevExpress.XtraPrinting.BorderSide)(((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Right)
+ | DevExpress.XtraPrinting.BorderSide.Bottom)));
+ this.xrTableCell42.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
+ new DevExpress.XtraReports.UI.XRBinding("Text", null, "ServiceInvoicePeriods.ServiceInvoiceItems.ServiceDescription")});
+ this.xrTableCell42.Name = "xrTableCell42";
+ this.xrTableCell42.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 2, 2, 100F);
+ this.xrTableCell42.StylePriority.UseBorderColor = false;
+ this.xrTableCell42.StylePriority.UseBorders = false;
+ this.xrTableCell42.StylePriority.UsePadding = false;
+ this.xrTableCell42.StylePriority.UseTextAlignment = false;
+ this.xrTableCell42.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleLeft;
+ this.xrTableCell42.Weight = 0.85081229498678679D;
+ //
+ // xrTableCell43
+ //
+ this.xrTableCell43.BorderColor = System.Drawing.Color.DarkGray;
+ this.xrTableCell43.Borders = ((DevExpress.XtraPrinting.BorderSide)(((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Right)
+ | DevExpress.XtraPrinting.BorderSide.Bottom)));
+ this.xrTableCell43.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
+ new DevExpress.XtraReports.UI.XRBinding("Text", null, "ServiceInvoicePeriods.ServiceInvoiceItems.HourlyRate", "{0:0.00}")});
+ this.xrTableCell43.Name = "xrTableCell43";
+ this.xrTableCell43.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 2, 2, 100F);
+ this.xrTableCell43.StylePriority.UseBorderColor = false;
+ this.xrTableCell43.StylePriority.UseBorders = false;
+ this.xrTableCell43.StylePriority.UsePadding = false;
+ this.xrTableCell43.StylePriority.UseTextAlignment = false;
+ this.xrTableCell43.Text = "xrTableCell43";
+ this.xrTableCell43.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
+ this.xrTableCell43.Weight = 0.23245943032832414D;
+ //
+ // xrTableCell44
+ //
+ this.xrTableCell44.BorderColor = System.Drawing.Color.DarkGray;
+ this.xrTableCell44.Borders = ((DevExpress.XtraPrinting.BorderSide)(((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Right)
+ | DevExpress.XtraPrinting.BorderSide.Bottom)));
+ this.xrTableCell44.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
+ new DevExpress.XtraReports.UI.XRBinding("Text", null, "ServiceInvoicePeriods.ServiceInvoiceItems.Hours", "{0:0.##}")});
+ this.xrTableCell44.Name = "xrTableCell44";
+ this.xrTableCell44.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 2, 2, 100F);
+ this.xrTableCell44.StylePriority.UseBorderColor = false;
+ this.xrTableCell44.StylePriority.UseBorders = false;
+ this.xrTableCell44.StylePriority.UsePadding = false;
+ this.xrTableCell44.StylePriority.UseTextAlignment = false;
+ this.xrTableCell44.Text = "xrTableCell44";
+ this.xrTableCell44.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
+ this.xrTableCell44.Weight = 0.2893277257020575D;
+ //
+ // xrTableCell45
+ //
+ this.xrTableCell45.BorderColor = System.Drawing.Color.DarkGray;
+ this.xrTableCell45.Borders = ((DevExpress.XtraPrinting.BorderSide)(((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Right)
+ | DevExpress.XtraPrinting.BorderSide.Bottom)));
+ this.xrTableCell45.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
+ new DevExpress.XtraReports.UI.XRBinding("Text", null, "ServiceInvoicePeriods.ServiceInvoiceItems.NetAmount", "{0:0.00}")});
+ this.xrTableCell45.Name = "xrTableCell45";
+ this.xrTableCell45.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 2, 2, 100F);
+ this.xrTableCell45.StylePriority.UseBorderColor = false;
+ this.xrTableCell45.StylePriority.UseBorders = false;
+ this.xrTableCell45.StylePriority.UsePadding = false;
+ this.xrTableCell45.StylePriority.UseTextAlignment = false;
+ this.xrTableCell45.Text = "xrTableCell45";
+ this.xrTableCell45.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
+ this.xrTableCell45.Weight = 0.26310971709438763D;
+ //
+ // xrTableCell46
+ //
+ this.xrTableCell46.BorderColor = System.Drawing.Color.DarkGray;
+ this.xrTableCell46.Borders = ((DevExpress.XtraPrinting.BorderSide)(((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Right)
+ | DevExpress.XtraPrinting.BorderSide.Bottom)));
+ this.xrTableCell46.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
+ new DevExpress.XtraReports.UI.XRBinding("Text", null, "ServiceInvoicePeriods.ServiceInvoiceItems.RateFactor")});
+ this.xrTableCell46.Name = "xrTableCell46";
+ this.xrTableCell46.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 2, 2, 100F);
+ this.xrTableCell46.StylePriority.UseBorderColor = false;
+ this.xrTableCell46.StylePriority.UseBorders = false;
+ this.xrTableCell46.StylePriority.UsePadding = false;
+ this.xrTableCell46.StylePriority.UseTextAlignment = false;
+ this.xrTableCell46.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
+ this.xrTableCell46.Weight = 0.42042083402151886D;
+ //
+ // xrTableCell47
+ //
+ this.xrTableCell47.BorderColor = System.Drawing.Color.DarkGray;
+ this.xrTableCell47.Borders = ((DevExpress.XtraPrinting.BorderSide)(((DevExpress.XtraPrinting.BorderSide.Left | DevExpress.XtraPrinting.BorderSide.Right)
+ | DevExpress.XtraPrinting.BorderSide.Bottom)));
+ this.xrTableCell47.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
+ new DevExpress.XtraReports.UI.XRBinding("Text", null, "ServiceInvoicePeriods.ServiceInvoiceItems.GrossAmount")});
+ this.xrTableCell47.Name = "xrTableCell47";
+ this.xrTableCell47.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 2, 2, 2, 100F);
+ this.xrTableCell47.StylePriority.UseBorderColor = false;
+ this.xrTableCell47.StylePriority.UseBorders = false;
+ this.xrTableCell47.StylePriority.UsePadding = false;
+ this.xrTableCell47.StylePriority.UseTextAlignment = false;
+ this.xrTableCell47.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
+ this.xrTableCell47.Weight = 0.31923915575667006D;
+ //
+ // GroupFooter1
+ //
+ this.GroupFooter1.Controls.AddRange(new DevExpress.XtraReports.UI.XRControl[] {
+ this.xrLabel1,
+ this.xrLabel9,
+ this.xrTable4,
+ this.xrLabel14,
+ this.xrLabel15});
+ this.GroupFooter1.HeightF = 206.5833F;
+ this.GroupFooter1.Name = "GroupFooter1";
+ //
+ // xrLabel1
+ //
+ this.xrLabel1.DataBindings.AddRange(new DevExpress.XtraReports.UI.XRBinding[] {
+ new DevExpress.XtraReports.UI.XRBinding("Text", null, "GrossClaim", "Gesamtsumme: {0}")});
+ this.xrLabel1.Font = new System.Drawing.Font("Verdana", 9F, System.Drawing.FontStyle.Bold);
+ this.xrLabel1.LocationFloat = new DevExpress.Utils.PointFloat(420.9999F, 0F);
+ this.xrLabel1.Name = "xrLabel1";
+ this.xrLabel1.Padding = new DevExpress.XtraPrinting.PaddingInfo(2, 5, 0, 0, 100F);
+ this.xrLabel1.SizeF = new System.Drawing.SizeF(255.8333F, 25F);
+ this.xrLabel1.StylePriority.UseFont = false;
+ this.xrLabel1.StylePriority.UsePadding = false;
+ this.xrLabel1.StylePriority.UseTextAlignment = false;
+ this.xrLabel1.Text = "xrLabel1";
+ this.xrLabel1.TextAlignment = DevExpress.XtraPrinting.TextAlignment.MiddleRight;
+ //
+ // bindingSource1
+ //
+ this.bindingSource1.DataSource = typeof(BeWo.Report.ReportObjects.ServiceInvoiceRO);
+ //
+ // ServiceInvoiceReport
+ //
+ this.Bands.AddRange(new DevExpress.XtraReports.UI.Band[] {
+ this.Detail,
+ this.ReportHeader,
+ this.topMarginBand1,
+ this.bottomMarginBand1,
+ this.Page1,
+ this.DetailReport});
+ this.DataSource = this.bindingSource1;
+ this.ExportOptions.PrintPreview.DefaultFileName = "Spitzabrechnung";
+ this.Font = new System.Drawing.Font("Verdana", 10F);
+ this.FormattingRuleSheet.AddRange(new DevExpress.XtraReports.UI.FormattingRule[] {
+ this.ruleRateFactorNull});
+ this.Margins = new System.Drawing.Printing.Margins(75, 75, 158, 50);
+ this.PageHeight = 1169;
+ this.PageWidth = 827;
+ this.PaperKind = System.Drawing.Printing.PaperKind.A4;
+ this.Version = "17.1";
+ ((System.ComponentModel.ISupportInitialize)(this.xrTable2)).EndInit();
+ ((System.ComponentModel.ISupportInitialize)(this.xrTable4)).EndInit();
+ ((System.ComponentModel.ISupportInitialize)(this.xrTable5)).EndInit();
+ ((System.ComponentModel.ISupportInitialize)(this.xrTable6)).EndInit();
+ ((System.ComponentModel.ISupportInitialize)(this.bindingSource1)).EndInit();
+ ((System.ComponentModel.ISupportInitialize)(this)).EndInit();
+
+ }
+
+
+ private DevExpress.XtraReports.UI.DetailBand Detail;
+ private System.Windows.Forms.BindingSource bindingSource1;
+ private DevExpress.XtraReports.UI.ReportHeaderBand ReportHeader;
+ private DevExpress.XtraReports.UI.FormattingRule ruleRateFactorNull;
+ private DevExpress.XtraReports.UI.TopMarginBand topMarginBand1;
+ private DevExpress.XtraReports.UI.BottomMarginBand bottomMarginBand1;
+ private DevExpress.XtraReports.UI.GroupHeaderBand Page1;
+ private DevExpress.XtraReports.UI.XRLabel xrLabel4;
+ private DevExpress.XtraReports.UI.XRLabel xrLabel3;
+ private DevExpress.XtraReports.UI.XRLabel xrLabel2;
+ private DevExpress.XtraReports.UI.XRLabel xrLabel5;
+ private DevExpress.XtraReports.UI.XRLabel xrLabel8;
+ private DevExpress.XtraReports.UI.XRLabel lblAbrechnungszeitraum;
+ private DevExpress.XtraReports.UI.XRTable xrTable2;
+ private DevExpress.XtraReports.UI.XRTableRow xrTableRow2;
+ private DevExpress.XtraReports.UI.XRTableCell xrTableCell4;
+ private DevExpress.XtraReports.UI.XRTableRow xrTableRow5;
+ private DevExpress.XtraReports.UI.XRTableCell xrTableCell13;
+ private DevExpress.XtraReports.UI.XRTableRow xrTableRow4;
+ private DevExpress.XtraReports.UI.XRTableCell xrTableCell11;
+ private DevExpress.XtraReports.UI.XRTableRow xrTableRow3;
+ private DevExpress.XtraReports.UI.XRTableCell xrTableCell8;
+ private DevExpress.XtraReports.UI.XRTableRow xrTableRow1;
+ private DevExpress.XtraReports.UI.XRTableCell xrTableCell1;
+ private DevExpress.XtraReports.UI.XRTableRow xrTableRow6;
+ private DevExpress.XtraReports.UI.XRTableCell xrTableCell2;
+ private DevExpress.XtraReports.UI.XRTableRow xrTableRow8;
+ private DevExpress.XtraReports.UI.XRTableCell xrTableCell5;
+ private DevExpress.XtraReports.UI.XRLabel xrLabel15;
+ private DevExpress.XtraReports.UI.XRTable xrTable4;
+ private DevExpress.XtraReports.UI.XRTableRow xrTableRow10;
+ private DevExpress.XtraReports.UI.XRTableCell xrTableCell9;
+ private DevExpress.XtraReports.UI.XRTableRow xrTableRow14;
+ private DevExpress.XtraReports.UI.XRTableCell xrTableCell12;
+ private DevExpress.XtraReports.UI.XRLabel xrLabel14;
+ private DevExpress.XtraReports.UI.XRLabel xrLabel9;
+ private DevExpress.XtraReports.UI.DetailReportBand DetailReport;
+ private DevExpress.XtraReports.UI.DetailBand Detail1;
+ private DevExpress.XtraReports.UI.XRTable xrTable5;
+ private DevExpress.XtraReports.UI.XRTableRow xrTableRow23;
+ private DevExpress.XtraReports.UI.XRTableCell xrTableCell32;
+ private DevExpress.XtraReports.UI.XRTableCell xrTableCell37;
+ private DevExpress.XtraReports.UI.XRTableCell xrTableCell35;
+ private DevExpress.XtraReports.UI.XRTableCell xrTableCell33;
+ private DevExpress.XtraReports.UI.XRTableCell xrTableCell36;
+ private DevExpress.XtraReports.UI.XRTableCell xrTableCell38;
+ private DevExpress.XtraReports.UI.XRTableCell xrTableCell34;
+ private DevExpress.XtraReports.UI.DetailReportBand DetailReport2;
+ private DevExpress.XtraReports.UI.DetailBand Detail3;
+ private DevExpress.XtraReports.UI.XRTable xrTable6;
+ private DevExpress.XtraReports.UI.XRTableRow xrTableRow25;
+ private DevExpress.XtraReports.UI.XRTableCell xrTableCell40;
+ private DevExpress.XtraReports.UI.XRTableCell xrTableCell42;
+ private DevExpress.XtraReports.UI.XRTableCell xrTableCell43;
+ private DevExpress.XtraReports.UI.XRTableCell xrTableCell44;
+ private DevExpress.XtraReports.UI.XRTableCell xrTableCell45;
+ private DevExpress.XtraReports.UI.XRTableCell xrTableCell46;
+ private DevExpress.XtraReports.UI.XRTableCell xrTableCell47;
+ private DevExpress.XtraReports.UI.XRLabel lblAdresse;
+ private DevExpress.XtraReports.UI.GroupFooterBand GroupFooter1;
+ private DevExpress.XtraReports.UI.XRLabel xrLabel1;
+ }
+}
diff --git a/ReportImp/BeWoDarmstadt/ServiceInvoiceReport.cs b/ReportImp/BeWoDarmstadt/ServiceInvoiceReport.cs
new file mode 100644
index 000000000..14b2e2375
--- /dev/null
+++ b/ReportImp/BeWoDarmstadt/ServiceInvoiceReport.cs
@@ -0,0 +1,65 @@
+using System;
+using System.Text;
+using BeWo.Report;
+using BeWo.Report.ReportObjects;
+
+using DevExpress.XtraReports.UI;
+
+namespace BeWoDarmstadt
+{
+ public partial class ServiceInvoiceReport : XtraReport, IBeWoReport
+ {
+ public ServiceInvoiceReport()
+ {
+ this.InitializeComponent();
+ }
+
+ public void SetReportDataSource(ServiceInvoiceRO pRO)
+ {
+ DateTime start = pRO.AccountingPeriodStart;
+ DateTime end = pRO.AccountingPeriodEnd;
+ StringBuilder sb = new StringBuilder();
+
+ if (!String.IsNullOrEmpty(pRO.RecipientOrganisation) && pRO.RecipientOrganisation != "Selbstzahler")
+ {
+ sb.AppendLine(pRO.RecipientOrganisation);
+ }
+ if (!String.IsNullOrEmpty(pRO.RecipientAddressLine1))
+ {
+ sb.AppendLine(pRO.RecipientAddressLine1);
+ }
+ if (!String.IsNullOrEmpty(pRO.RecipientContactPerson))
+ {
+ sb.AppendLine(pRO.RecipientContactPerson);
+ }
+ if (!String.IsNullOrEmpty(pRO.RecipientDivision) && !String.IsNullOrEmpty(pRO.RecipientOrganisation) && pRO.RecipientOrganisation != "SELBSTZAHLER")
+ {
+ sb.AppendLine(pRO.RecipientDivision);
+ }
+ else if (!String.IsNullOrEmpty(pRO.RecipientPoBox))
+ {
+ sb.AppendLine(pRO.RecipientPoBox);
+ }
+ else if (!String.IsNullOrEmpty(pRO.RecipientStreet))
+ {
+ sb.AppendLine(pRO.RecipientStreet);
+ }
+ if (!String.IsNullOrEmpty(pRO.RecipientPostCodeAndTown))
+ {
+ sb.AppendLine(pRO.RecipientPostCodeAndTown);
+ }
+ lblAdresse.Text = sb.ToString();
+
+ if (start.Month == end.Month && start.Year == end.Year)
+ {
+ lblAbrechnungszeitraum.Text = String.Format("hiermit berechnen wir für den Monat {0:MMMM yyyy} folgende erbrachte Tätigkeiten:", start);
+ }
+ else
+ {
+ lblAbrechnungszeitraum.Text = String.Format("hiermit berechnen wir für den Zeitraum {0:MMMM yyyy} - {1:MMMM yyyy} folgende erbrachte Tätigkeiten:", start, end);
+ }
+
+ this.bindingSource1.DataSource = pRO;
+ }
+ }
+}
\ No newline at end of file
diff --git a/ReportImp/BeWoDarmstadt/ServiceInvoiceReport.resx b/ReportImp/BeWoDarmstadt/ServiceInvoiceReport.resx
new file mode 100644
index 000000000..d25f3eba2
--- /dev/null
+++ b/ReportImp/BeWoDarmstadt/ServiceInvoiceReport.resx
@@ -0,0 +1,123 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ text/microsoft-resx
+
+
+ 2.0
+
+
+ System.Resources.ResXResourceReader, System.Windows.Forms, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089
+
+
+ System.Resources.ResXResourceWriter, System.Windows.Forms, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089
+
+
+ 17, 17
+
+
\ No newline at end of file
diff --git a/ReportImp/BeWoDarmstadt/Zeitzuschlagsbeleg.Designer.cs b/ReportImp/BeWoDarmstadt/Zeitzuschlagsbeleg.Designer.cs
index 9da7cfd91..4729ff5e6 100644
--- a/ReportImp/BeWoDarmstadt/Zeitzuschlagsbeleg.Designer.cs
+++ b/ReportImp/BeWoDarmstadt/Zeitzuschlagsbeleg.Designer.cs
@@ -3297,7 +3297,6 @@ namespace BeWoDarmstadt
this.xrTableCell1091.Font = new System.Drawing.Font("Arial", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.xrTableCell1091.Name = "xrTableCell1091";
this.xrTableCell1091.StylePriority.UseFont = false;
- this.xrTableCell1091.Text = "8,00";
this.xrTableCell1091.Weight = 0.017513894293788093D;
//
// xrTableCell1092
@@ -9356,7 +9355,6 @@ namespace BeWoDarmstadt
this.xrTableCell144.Font = new System.Drawing.Font("Arial", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
this.xrTableCell144.Name = "xrTableCell144";
this.xrTableCell144.StylePriority.UseFont = false;
- this.xrTableCell144.Text = "11,00";
this.xrTableCell144.Weight = 0.017513890118150417D;
//
// xrTableCell145
@@ -10153,7 +10151,7 @@ namespace BeWoDarmstadt
//
// xrTableRow9
//
- this.xrTableRow9.BackColor = System.Drawing.Color.Transparent;
+ this.xrTableRow9.BackColor = System.Drawing.Color.Gainsboro;
this.xrTableRow9.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
this.xrTableCell143,
this.xrTableCell282,
@@ -10444,7 +10442,7 @@ namespace BeWoDarmstadt
//
// xrTableRow2
//
- this.xrTableRow2.BackColor = System.Drawing.Color.Gainsboro;
+ this.xrTableRow2.BackColor = System.Drawing.Color.Transparent;
this.xrTableRow2.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
this.xrTableCell175,
this.xrTableCell72,
@@ -10764,7 +10762,7 @@ namespace BeWoDarmstadt
//
// xrTableRow3
//
- this.xrTableRow3.BackColor = System.Drawing.Color.Transparent;
+ this.xrTableRow3.BackColor = System.Drawing.Color.Gainsboro;
this.xrTableRow3.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
this.xrTableCell209,
this.xrTableCell107,
@@ -11084,7 +11082,7 @@ namespace BeWoDarmstadt
//
// xrTableRow4
//
- this.xrTableRow4.BackColor = System.Drawing.Color.Gainsboro;
+ this.xrTableRow4.BackColor = System.Drawing.Color.Transparent;
this.xrTableRow4.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
this.xrTableCell213,
this.xrTableCell141,
@@ -11404,7 +11402,7 @@ namespace BeWoDarmstadt
//
// xrTableRow5
//
- this.xrTableRow5.BackColor = System.Drawing.Color.Transparent;
+ this.xrTableRow5.BackColor = System.Drawing.Color.Gainsboro;
this.xrTableRow5.Cells.AddRange(new DevExpress.XtraReports.UI.XRTableCell[] {
this.xrTableCell248,
this.xrTableCell208,
@@ -12235,7 +12233,7 @@ namespace BeWoDarmstadt
//
// rzSoll
//
- this.rzSoll.Expression = "[StundenSollMax]-[FlsSoll]";
+ this.rzSoll.Expression = "[StundenSollOhneUrlaubKrankheit]-[FlsSoll]";
this.rzSoll.Name = "rzSoll";
//
// FlsGleitzeit
diff --git a/ReportImp/BeWoDarmstadt/Zeitzuschlagsbeleg.cs b/ReportImp/BeWoDarmstadt/Zeitzuschlagsbeleg.cs
index 84774d782..88d7d36f7 100644
--- a/ReportImp/BeWoDarmstadt/Zeitzuschlagsbeleg.cs
+++ b/ReportImp/BeWoDarmstadt/Zeitzuschlagsbeleg.cs
@@ -54,6 +54,7 @@ namespace BeWoDarmstadt
public void SetReportDataSource(DateTime monat, MitarbeiterstundenkontoRO.EmployeeDetail ed)
{
ed.FirstName = "";
+ DateTime ende = monat.AddMonths(1);
if (ed.Custom9 > 0 || ed.Custom8 > 0)
{
@@ -67,43 +68,46 @@ namespace BeWoDarmstadt
lblZeitraum.Text = String.Format("{0:MMMM yyyy}", monat);
lblStelle.Text = String.Format("{0:0.00}", ed.SollProWoche/40);
- decimal anteilFLS = (decimal)ed.WeeklyFLS / (decimal)ed.SollProWoche;
- foreach (var ot in ed.Employee.Overtimes)
+ decimal anteilFLS = (decimal)0.75; //(decimal)ed.WeeklyFLS / (decimal)ed.SollProWoche;
+ //foreach (var ot in ed.Employee.Overtimes)
+ //{
+ // ed.Custom6 += ot.Betrag;
+ //}
+ if (ed.UeberstundenVormonat != null)
{
- ed.Custom6 += ot.Betrag;
+ if (ed.UeberstundenVormonat < 0 && ed.Custom15 > 0)
+ ed.Custom14 = (decimal)ed.UeberstundenVormonat + ed.Custom15;
+ else
+ ed.Custom14 = (decimal)ed.UeberstundenVormonat - ed.Custom15; // Überstunden Vormonate nur Mittelbare
}
- ed.Custom14 = (decimal)ed.UeberstundenVormonat - ed.Custom15 + ed.Custom6 * anteilFLS; ; // Überstunden Vormonate nur Mittelbare
- ed.Custom15 = ed.Custom15 - ed.Custom6 * anteilFLS; // Überstunden Vormonate nur FLS unter Berücksichtigung Auszahlung
- ed.Ueberstunden = ed.Ueberstunden - ed.FlsDiff; // Überstunden nur Mittelbare
- ed.Custom13 = ed.Custom15 + ed.FlsDiff; //ÜberstundenGesamt nur FLS
-
-
- if (ed.UeberstundenAusbezahlt != 0)
+ var emp = ed.Employee;
+ if (emp.Overtimes != null)
{
- var emp = ed.Employee;
- if (emp.Overtimes != null)
+ foreach (var ot in emp.Overtimes)
{
- foreach (var ot in emp.Overtimes)
+ if (ot.Date < monat)
{
- if (ot.Date >= start && ot.Date < ende)
- {
- if (ot.Auszahlungsart.Name.Contains("FLS"))
- stunden += ot.Betrag;
- else if (ot.Auszahlungsart.Name.Contains("Rahmenzeit"))
- stundenRz += ot.Betrag;
- }
+ if (ot.Auszahlungsart.Name.Contains("FLS"))
+ ed.Custom15 += ot.Betrag; // Überstunden Vormonate nur FLS unter Berücksichtigung Auszahlung
+ else if (ot.Auszahlungsart.Name.Contains("Rahmenzeit"))
+ ed.Custom14 += ot.Betrag; // Überstunden Vormonate nur Mittelbare
+ }
+ if (ot.Date >= monat && ot.Date < ende)
+ {
+ if (ot.Auszahlungsart.Name.Contains("FLS"))
+ ed.Custom12 -= ot.Betrag;
+ else if (ot.Auszahlungsart.Name.Contains("Rahmenzeit"))
+ ed.Custom11 -= ot.Betrag;
}
}
- ed.Custom12 = ed.UeberstundenAusbezahlt * anteilFLS;
- ed.Custom11 = (decimal)ed.UeberstundenAusbezahlt - (decimal)ed.UeberstundenAusbezahlt * anteilFLS;
}
- ed.Custom10 = ed.FlsDiff - ed.Custom12;
- ed.Custom9 = (decimal)ed.Ueberstunden - ed.Custom11;
-
- ed.Custom8 = ed.Custom15 + ed.Custom10; //ÜberstundenGesamt nur FLS - abzgl. Auszahlung anteilig
- ed.Custom7 = ed.Custom14 + ed.Custom9; // ÜberstundenGesamt nur MB -abzgl.Auszahlung anteilig
+ ed.Ueberstunden = ed.Ueberstunden - ed.FlsDiff; // Überstunden nur Mittelbare
+ ed.Custom10 = ed.FlsDiff - ed.Custom12; // Überstunden lfd. Monat nach Auszahlung nur FLS
+ ed.Custom9 = (decimal)ed.Ueberstunden - ed.Custom11; // Überstunden lfd. Monat nach Auszahlung nur mittelbare
+ ed.Custom8 = ed.Custom15 + ed.Custom10; // ÜberstundenGesamt nur FLS - abzgl. Auszahlung anteilig
+ ed.Custom7 = ed.Custom14 + ed.Custom9; // ÜberstundenGesamt nur MB -abzgl.Auszahlung anteilig
this.bindingSource1.DataSource = ed;
}
@@ -227,14 +231,14 @@ namespace BeWoDarmstadt
cell.Font = new Font(cell.Font.FontFamily, 7, FontStyle.Regular);
}
- bool setBackground = false;
+ //bool setBackground = false;
- setBackground = !isHeaderRow || (maxDays < 31 && cellIdx > maxDays + 1 && cellIdx <= 32);
+ //setBackground = !isHeaderRow || (maxDays < 31 && cellIdx > maxDays + 1 && cellIdx <= 32);
- if (setBackground)
- {
- cell.BackColor = Color.LightGray;
- }
+ //if (setBackground)
+ //{
+ // cell.BackColor = Color.LightGray;
+ //}
}
cellIdx++;
}